@@ -1006,7 +1006,7 @@ struct versionOption : public option {
     eigen=true;
 #endif
 
-#ifdef HAVE_RPC_RPC_H
+#ifdef HAVE_LIBTIRPC
     xdr=true;
 #endif
 
@@ -1252,6 +1252,8 @@ void initSettings() {
                             "Emulate unimplemented SVG shading", true));
   addOption(new boolSetting("prc", 0,
                             "Embed 3D PRC graphics in PDF output", false));
+  addOption(new boolSetting("v3d", 0,
+                            "Embed 3D V3D graphics in PDF output", false));
   addOption(new boolSetting("toolbar", 0,
                             "Show 3D toolbar in PDF output", true));
   addOption(new boolSetting("axes3", 0,
@@ -1391,7 +1393,7 @@ void initSettings() {
                                       "Allow read from other directory",
                                       &globalRead, true));
   addSecureSetting(new stringSetting("outname", 'o', "name",
-                                     "Alternative output directory/filename"));
+                                     "Alternative output directory/file prefix"));
   addOption(new stringOption("cd", 0, "directory", "Set current directory",
                              &startpath));
 
@@ -1411,10 +1413,13 @@ void initSettings() {
                             "Input code over multiple lines at the prompt"));
   addOption(new boolSetting("xasy", 0,
                             "Interactive mode for xasy"));
+#ifdef HAVE_LSP
   addOption(new boolSetting("lsp", 0, "Interactive mode for the Language Server Protocol"));
-  addOption(new boolSetting("wsl", 0, "Run asy under the Windows Subsystem for Linux."));
   addOption(new envSetting("lspport", ""));
   addOption(new envSetting("lsphost", "127.0.0.1"));
+#endif
+
+  addOption(new boolSetting("wsl", 0, "Run asy under the Windows Subsystem for Linux"));
 
   addOption(new boolSetting("wait", 0,
                             "Wait for child processes to finish before exiting"));
@@ -1482,7 +1487,7 @@ void initSettings() {
   addOption(new realSetting("paperheight", 0, "bp", "Default page height"));
 
   addOption(new stringSetting("dvipsOptions", 0, "str", ""));
-  addOption(new stringSetting("dvisvgmOptions", 0, "str", ""));
+  addOption(new stringSetting("dvisvgmOptions", 0, "str", "", "--optimize"));
   addOption(new boolSetting("dvisvgmMultipleFiles", 0,
                             "dvisvgm supports multiple files", true));
   addOption(new stringSetting("convertOptions", 0, "str", ""));
